repl

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2025 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

repl package is responsible for handling the file mode (repl mode is not supported) which reads the entire file content and evaluates the entire program at once.

This is useful when you want to use variables defined on one line in another line. StartFileAllAtOnce reads the entire file content and evaluates the entire program at once.

Index

Constants

const MONKEY_FACE = `` /* 231-byte string literal not displayed */
const PROMPT = ">> "

Variables

This section is empty.

Functions

func Start

func Start(in io.Reader, out io.Writer)

func StartFile

func StartFile(path string)

func StartFileAllAtOnce

func StartFileAllAtOnce(path string)

StartFileAllAtOnce reads the entire file content and evaluates the entire program at once. This helps when, for instance, you want to use variables defined on one line in another line.

func StartLexer

func StartLexer(path string)

func StartRPPL

func StartRPPL(in io.Reader, out io.Writer)

Types

This section is empty.

Jump to