Documentation
¶
Overview ¶
repl package is responsible for handling the file mode (repl mode is not supported) which reads the entire file content and evaluates the entire program at once.
This is useful when you want to use variables defined on one line in another line. StartFileAllAtOnce reads the entire file content and evaluates the entire program at once.
Index ¶
Constants ¶
const MONKEY_FACE = `` /* 231-byte string literal not displayed */
const PROMPT = ">> "
Variables ¶
This section is empty.
Functions ¶
func StartFileAllAtOnce ¶
func StartFileAllAtOnce(path string)
StartFileAllAtOnce reads the entire file content and evaluates the entire program at once. This helps when, for instance, you want to use variables defined on one line in another line.
func StartLexer ¶
func StartLexer(path string)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.